@@ -47,7 +47,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <errno.h>
-#include <sys/poll.h>
+#include <poll.h>
 
 #define BUFFER_LENGTH 512
 
